FontSizeController class

Controls global font size, font family, accent color, and all other 20+ appearance preferences. Use changeXXX to persist a setting permanently. Use applyXXXPreview for transient live-previews (does NOT write to storage).

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • FontSizeController
Implemented types

Constructors

FontSizeController()

Properties

accentColor → Rx<AppAccentColor>
final
actionButtonColor → Rx<AppActionButtonColor>
final
actionButtonShape → Rx<AppActionButtonShape>
final
actionButtonStyle → Rx<AppActionButtonStyle>
final
animationsEnabled → RxBool
final
appBarHeight → Rx<AppAppBarHeight>
final
appBarShadow → Rx<AppAppBarShadow>
final
appBarStyle → Rx<AppAppBarStyle>
final
appBarTitleAlignment → Rx<AppAppBarTitleAlignment>
final
borderRadius → Rx<AppBorderRadius>
final
buttonStyle → Rx<AppButtonStyle>
final
cardElevation → Rx<AppCardElevation>
final
contentWidth → Rx<AppContentWidth>
final
customAccentColorHex → RxString
final
customSidebarColorHex → RxString
final
customSidebarTextColorHex → RxString
final
dataGridTemplate → Rx<AppDataGridTemplate>
final
fontFamily → Rx<AppFontFamily>
final
fontLetterSpacing → Rx<AppFontLetterSpacing>
final
fontLineHeight → Rx<AppFontLineHeight>
final
fontSize → Rx<AppFontSize>
final
gridSize → Rx<AppGridSize>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
inputStyle → Rx<AppInputFieldStyle>
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
layoutDensity → Rx<AppLayoutDensity>
final
listeners int
no setterinherited
final
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
pageTransition → Rx<AppPageTransition>
final
pushNotifications → RxBool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor double
no setter
shadowsEnabled → RxBool
final
sidebarActiveColor → Rx<SidebarActiveColorOption>
final
sidebarColor → Rx<AppSidebarColor>
final
sidebarHoverColor → Rx<SidebarHoverColorOption>
final
sidebarIconSize → Rx<SidebarIconSizeOption>
final
sidebarPosition → Rx<AppSidebarPosition>
final
sidebarTransparency → RxBool
final
sidebarWidth → Rx<AppSidebarWidth>
final
tableRowHeight → Rx<AppTableRowHeight>
final
themeMode → Rx<AppThemeMode>
final
uiScale → Rx<AppUiScale>
final
uiStyle → Rx<AppUiStyle>
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
applyAccentColorPreview(AppAccentColor color) → void
applyActionButtonColorPreview(AppActionButtonColor color) → void
applyActionButtonShapePreview(AppActionButtonShape shape) → void
applyActionButtonStylePreview(AppActionButtonStyle style) → void
applyAnimationsEnabledPreview(bool enabled) → void
applyAppBarHeightPreview(AppAppBarHeight height) → void
applyAppBarShadowPreview(AppAppBarShadow shadow) → void
applyAppBarStylePreview(AppAppBarStyle style) → void
applyAppBarTitleAlignmentPreview(AppAppBarTitleAlignment align) → void
applyBorderRadiusPreview(AppBorderRadius radius) → void
applyButtonStylePreview(AppButtonStyle style) → void
applyCardElevationPreview(AppCardElevation elevation) → void
applyContentWidthPreview(AppContentWidth width) → void
applyCustomAccentColorPreview(String hex) → void
applyCustomSidebarColorPreview(String hex) → void
applyCustomSidebarTextColorPreview(String hex) → void
applyDataGridTemplatePreview(AppDataGridTemplate template) → void
applyFontFamilyPreview(AppFontFamily family) → void
applyFontLetterSpacingPreview(AppFontLetterSpacing spacing) → void
applyFontLineHeightPreview(AppFontLineHeight height) → void
applyFontSizePreview(AppFontSize size) → void
applyGridSizePreview(AppGridSize size) → void
applyInputStylePreview(AppInputFieldStyle style) → void
applyLayoutDensityPreview(AppLayoutDensity density) → void
applyNavigationStylePreview(AppNavigationStyle style) → void
applyPageTransitionPreview(AppPageTransition transition) → void
applyPushNotificationsPreview(bool enabled) → void
applyShadowsEnabledPreview(bool enabled) → void
applySidebarActiveColorPreview(SidebarActiveColorOption option) → void
applySidebarColorPreview(AppSidebarColor color) → void
applySidebarHoverColorPreview(SidebarHoverColorOption option) → void
applySidebarIconSizePreview(SidebarIconSizeOption option) → void
applySidebarPositionPreview(AppSidebarPosition position) → void
applySidebarTransparencyPreview(bool enabled) → void
applySidebarWidthPreview(AppSidebarWidth width) → void
applyTableRowHeightPreview(AppTableRowHeight height) → void
applyThemeModePreview(AppThemeMode mode) → void
applyUiScalePreview(AppUiScale scale) → void
applyUiStylePreview(AppUiStyle style) → void
changeAccentColor(AppAccentColor color) → void
changeActionButtonColor(AppActionButtonColor color) → void
changeActionButtonShape(AppActionButtonShape shape) → void
changeActionButtonStyle(AppActionButtonStyle style) → void
changeAnimationsEnabled(bool enabled) → void
changeAppBarHeight(AppAppBarHeight height) → void
changeAppBarShadow(AppAppBarShadow shadow) → void
changeAppBarStyle(AppAppBarStyle style) → void
changeAppBarTitleAlignment(AppAppBarTitleAlignment align) → void
changeBorderRadius(AppBorderRadius radius) → void
changeButtonStyle(AppButtonStyle style) → void
changeCardElevation(AppCardElevation elevation) → void
changeContentWidth(AppContentWidth width) → void
changeCustomAccentColor(String hex) → void
changeCustomSidebarColor(String hex) → void
changeCustomSidebarTextColor(String hex) → void
changeDataGridTemplate(AppDataGridTemplate template) → void
changeFontFamily(AppFontFamily family) → void
changeFontLetterSpacing(AppFontLetterSpacing spacing) → void
changeFontLineHeight(AppFontLineHeight height) → void
changeFontSize(AppFontSize size) → void
changeGridSize(AppGridSize size) → void
changeInputStyle(AppInputFieldStyle style) → void
changeLayoutDensity(AppLayoutDensity density) → void
changeNavigationStyle(AppNavigationStyle style) → void
changePageTransition(AppPageTransition transition) → void
changePushNotifications(bool enabled) → void
changeShadowsEnabled(bool enabled) → void
changeSidebarActiveColor(SidebarActiveColorOption option) → void
changeSidebarColor(AppSidebarColor color) → void
changeSidebarHoverColor(SidebarHoverColorOption option) → void
changeSidebarIconSize(SidebarIconSizeOption option) → void
changeSidebarPosition(AppSidebarPosition position) → void
changeSidebarTransparency(bool enabled) → void
changeSidebarWidth(AppSidebarWidth width) → void
changeTableRowHeight(AppTableRowHeight height) → void
changeThemeMode(AppThemeMode mode) → void
changeUiScale(AppUiScale scale) → void
changeUiStyle(AppUiStyle style) → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getEffectiveAccentColor() Color
getEffectiveSidebarColor() Color
getEffectiveSidebarTextColor() Color
loadSavedPreferences() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited