HomeController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • HomeController
Implemented types

Constructors

HomeController()

Properties

cardColor ↔ Rx<Color>
getter/setter pair
currentEndDrawerContent ↔ Rxn<Widget>
getter/setter pair
environment Environment
getter/setter pair
eventsList ↔ RxList<EventsResponse>
getter/setter pair
financeApps List<Product>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isLoading ↔ RxBool
getter/setter pair
listeners int
no setterinherited
locationController LocationController
final
final
notificationCount ↔ Rx<int>
getter/setter pair
notificationList ↔ RxList<NotificationsResponse>
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesAndMarketing List<Product>
final
searchController TextEditingController
getter/setter pair
searchQuery ↔ RxString
getter/setter pair
selectedEventTypeValue ↔ Rx<SiteType>
getter/setter pair
serviceApps List<Product>
final
sessionController SessionController
final
showOldPlatformNote ↔ RxBool
getter/setter pair
storageUtils StorageUtils
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
changeColor(Color color) → void
changePassword() → void
checkAllPermissions() → void
clearData() → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
eventTypeValueChange(Set<SiteType> value) → void
fetchAllAPIs() → void
fetchHomePermission() Future<void>
filterApps(List<Product> products) List<Product>
getEvents(int newType) Future<void>
getLiveActiveModules() Future<Set<int>>
getNotifications() Future<void>
handleError(dynamic error) → void
increaseNotificationCount() → void
initData() → void
logOutAPI() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
postLogOutAPI() → void
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
setEndDrawerContent(BuildContext context, Widget view, {GlobalKey<ScaffoldState>? scaffoldKey}) → void
showLanguagePopup(BuildContext context) → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateLocal(Locale locale) → void
updateOldPlatformVisibility(List<Product> items, Set<int?> oldPlatformModuleIds) → void
updateSearchQuery(String query) → void
updateVisibility(List<Product> items, Set<int?> allowedModuleIds) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited