handleError method
void
handleError(
- dynamic error
Implementation
void handleError(dynamic error) {
// Log the error or show error message to the user
print('API error: $error');
}
void handleError(dynamic error) {
// Log the error or show error message to the user
print('API error: $error');
}