Product class

Constructors

Product({required int moduleId, required String label, required IconData icon, required Color iconColor, bool isVisible = false, required bool isOldPlatform})

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
getter/setter pair
iconColor Color
getter/setter pair
isOldPlatform bool
getter/setter pair
isVisible ↔ RxBool
getter/setter pair
label String
getter/setter pair
moduleId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited