InternalTransferWeighingController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • InternalTransferWeighingController
Implemented types

Constructors

InternalTransferWeighingController({required VoidCallback onCallback, required ValueChanged<bool> isLoading})

Properties

allWeighingMachineList ↔ RxList<WeighingMachineTO>
getter/setter pair
AutoWeighingTO WeighingTO
getter/setter pair
calibrationMachineId ↔ Rxn<CalibrationMachineData>
getter/setter pair
currentSelectedGate ↔ RxInt
getter/setter pair
diffWeightTO → Rx<TblTRLoadingWeighingTO>
final
finalTblTRLoadingWeighingTO ↔ Rx<TblTRLoadingWeighingTO>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isAutoWeighing ↔ RxBool
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isConfirmButtonEnabled ↔ RxBool
getter/setter pair
isConfirmed ↔ RxBool
getter/setter pair
isEnableCompleteWeighingBtn ↔ RxBool
getter/setter pair
isLoading ValueChanged<bool>
final
isOpenGatemanually ↔ RxBool
getter/setter pair
isPlayBtnPressed ↔ RxBool
getter/setter pair
isPlayButtonEnabled ↔ RxBool
getter/setter pair
listeners int
no setterinherited
loadingTypeId ↔ RxInt
getter/setter pair
loadingWeighingTO TblTRLoadingWeighingTO
getter/setter pair
loadingWeighingTOList ↔ RxList<TblTRLoadingWeighingTO>
getter/setter pair
loadingWeightTO → Rx<TblTRLoadingWeighingTO>
final
manualGateOpenTO ManualGateOpenTO
getter/setter pair
measurementController ↔ Rx<TextEditingController>
getter/setter pair
narrationController TextEditingController
getter/setter pair
narrationGateController ↔ Rx<TextEditingController>
getter/setter pair
narrationGateKey GlobalKey<FormState>
final
negotiationValue ↔ RxDouble
getter/setter pair
nextEqCode String
getter/setter pair
onCallback VoidCallback
final
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
retryPressCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedEqCode String
getter/setter pair
selectKata ↔ Rxn<DropDownResponse>
getter/setter pair
selectVehicleNo ↔ Rxn<DropDownResponse>
getter/setter pair
selectWeighingKata ↔ Rxn<DropDownResponse>
getter/setter pair
showKataTakenNote ↔ RxBool
getter/setter pair
tblTRLoadingTO → Rxn<TblTRLoadingTO>
final
tblTRLoadingWeighingTO TblTRLoadingWeighingTO
getter/setter pair
tblTRLoadingWeighingTOList ↔ RxList<TblTRLoadingWeighingTO>
getter/setter pair
tempTblTRLoadingTO → Rx<TblTRLoadingTO>
final
tempTblTRLoadingWeighingTOList ↔ RxList<TblTRLoadingWeighingTO>
getter/setter pair
unloadingWeightTO → Rx<TblTRLoadingWeighingTO>
final
vehicleImage String
getter/setter pair
WBAutoWeighingTO WeighingTO
getter/setter pair
WbForWeigingComplate WeighingTO
getter/setter pair
weighingKataList ↔ RxList<DropDownResponse>
getter/setter pair
wtFtNotFoundCmt String
getter/setter pair
wtMismatchCmt String
getter/setter pair
wtVehicleNoMismatchCmt String
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
AutoWeighingMachineDtls() Future<bool>
buildDivider() Widget
buildNarrationField() Widget
clearGateOpen() → void
confirmWeight() → dynamic
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getDiffWeight(String weighingMeasureTypeIdStr) num
getLatestCalibrationValByMachineId(int weighingMachineId) → void
getLoadingDetails() Future<void>
getWeighingDetails() Future<void>
getWeighingDetailsByLoadingTypeId() Future<void>
getWeighingKata() → dynamic
handleWeighingStatus() Future<void>
increaseRetryCount() → dynamic
initializeApi() → dynamic
isWtCompletebtnDisabled() bool
KataChanged() → dynamic
manualGateOpen() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onAutoWeighingValueChanged(bool? value) → void
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onKataChanged(DropDownResponse? value, {bool skipWeighingChange = false}) → void
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onScreenChange(int index) → dynamic
onVehicleNumberChanged(DropDownResponse? value) → void
onWeighingChange() → dynamic
onWeighingKataChanged(DropDownResponse? value) → void
openGate() → void
openLeftGate() → void
openRightGate() → void
postDirectGateOpenEvent() → void
postWeighingDetails() Future<void>
prepareWeighingDiffScreen() → void
processPostWeighingDetails() Future<void>
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
refreshVehicleDetailsList() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
removeSpaceFromString(String? input) String
resetData() → dynamic
setWeighingData() → void
showConfirmationDialog(String message) Future<bool?>
showConfirmationForOpenGate() → dynamic
showInformationDialog(String data) → dynamic
showOpenGateNarrationPopup() → dynamic
showVerifiedVehicleImageModal() → void
showWeighingDiffDialog() → void
toggleGate(String eqCode) Future<void>
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateWeighingRemark() → dynamic
verifyVehicleForOpenGateOnWeighing(String eqCode) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited