UserPermission enum

Inheritance
Available extensions

Values

all → const UserPermission
const UserPermission(1)
read → const UserPermission
const UserPermission(2)
write → const UserPermission
const UserPermission(3)
none → const UserPermission
const UserPermission(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromId(int id) UserPermission

Constants

values → const List<UserPermission>
A constant List of the values in this enum, in order of their declaration.