PreferencesController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • PreferencesController
Implemented types

Constructors

PreferencesController()

Properties

currentUserRole ↔ RxString
getter/setter pair
draftAccentColor → Rx<AppAccentColor>
final
draftActionButtonColor → Rx<AppActionButtonColor>
final
draftActionButtonShape → Rx<AppActionButtonShape>
final
draftActionButtonStyle → Rx<AppActionButtonStyle>
final
draftAnimationsEnabled → RxBool
final
draftAppBarHeight → Rx<AppAppBarHeight>
final
draftAppBarShadow → Rx<AppAppBarShadow>
final
draftAppBarStyle → Rx<AppAppBarStyle>
final
draftAppBarTitleAlignment → Rx<AppAppBarTitleAlignment>
final
draftBorderRadius → Rx<AppBorderRadius>
final
draftButtonStyle → Rx<AppButtonStyle>
final
draftCardElevation → Rx<AppCardElevation>
final
draftContentWidth → Rx<AppContentWidth>
final
draftCustomAccentColorHex → RxString
final
draftCustomLoaderColorHex → RxString
final
draftCustomSidebarColorHex → RxString
final
draftCustomSidebarTextColorHex → RxString
final
draftDataGridTemplate → Rx<AppDataGridTemplate>
final
draftFontFamily → Rx<AppFontFamily>
final
draftFontLetterSpacing → Rx<AppFontLetterSpacing>
final
draftFontLineHeight → Rx<AppFontLineHeight>
final
draftFontSize → Rx<AppFontSize>
final
draftGridSize → Rx<AppGridSize>
final
draftInputStyle → Rx<AppInputFieldStyle>
final
draftLayoutDensity → Rx<AppLayoutDensity>
final
draftLoaderColor → Rx<AppLoaderColor>
final
draftLoaderType → Rx<AppLoaderType>
final
draftNavigationStyle → Rx<AppNavigationStyle>
final
draftPageTransition → Rx<AppPageTransition>
final
draftPushNotifications → RxBool
final
draftShadowsEnabled → RxBool
final
draftSidebarActiveColor → Rx<SidebarActiveColorOption>
final
draftSidebarColor → Rx<AppSidebarColor>
final
draftSidebarHoverColor → Rx<SidebarHoverColorOption>
final
draftSidebarIconSize → Rx<SidebarIconSizeOption>
final
draftSidebarPosition → Rx<AppSidebarPosition>
final
draftSidebarTransparency → RxBool
final
draftSidebarWidth → Rx<AppSidebarWidth>
final
draftTableRowHeight → Rx<AppTableRowHeight>
final
draftThemeMode → Rx<AppThemeMode>
final
draftToastStyle → Rx<AppToastStyle>
final
draftUiScale → Rx<AppUiScale>
final
draftUiStyle → Rx<AppUiStyle>
final
fontSizeController FontSizeController
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
hasUnsavedChanges → RxBool
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDarkMode ↔ RxBool
getter/setter pair
isSaving → RxBool
final
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
organizationHierarchyList ↔ RxList<OrganizationHierarchyData>
getter/setter pair
pushNotificationsEnabled → Rx<bool>
no setter
roleList ↔ RxList<DropDownResponse>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedFontSize → Rx<AppFontSize>
no setter
selectedLanguage ↔ RxString
getter/setter pair
storageUtils StorageUtils
final
themeMode → Rx<AppThemeMode>
no setter
themeService ThemeService
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
changeFontSize(AppFontSize size) → void
Legacy alias kept for backward compatibility in existing callers.
changeLanguage(String language) → void
discardDrafts() → void
Revert all drafts back to the last saved state (discard changes).
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
initData() → void
Legacy initData — kept for any callers that invoke it directly.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
openRoleManagerDialog() Future<void>
refresh() → void
inherited
refreshDraftsFromStorage() → void
Call this when the Preferences screen is opened to ensure drafts always start from the latest persisted state.
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
resetToDefaults() → void
Reset all drafts to application defaults.
saveChanges() Future<void>
Persist all draft values to storage and make them the new saved baseline.
setDraftAccentColor(AppAccentColor color) → void
setDraftActionButtonColor(AppActionButtonColor color) → void
setDraftActionButtonShape(AppActionButtonShape shape) → void
setDraftActionButtonStyle(AppActionButtonStyle style) → void
setDraftAnimationsEnabled(bool enabled) → void
setDraftAppBarHeight(AppAppBarHeight height) → void
setDraftAppBarShadow(AppAppBarShadow shadow) → void
setDraftAppBarStyle(AppAppBarStyle style) → void
setDraftAppBarTitleAlignment(AppAppBarTitleAlignment align) → void
setDraftBorderRadius(AppBorderRadius radius) → void
setDraftButtonStyle(AppButtonStyle style) → void
setDraftCardElevation(AppCardElevation elevation) → void
setDraftContentWidth(AppContentWidth width) → void
setDraftCustomAccentColor(String hex) → void
setDraftCustomLoaderColor(String hex) → void
setDraftCustomSidebarColor(String hex) → void
setDraftCustomSidebarTextColor(String hex) → void
setDraftDataGridTemplate(AppDataGridTemplate template) → void
setDraftFontFamily(AppFontFamily family) → void
setDraftFontLetterSpacing(AppFontLetterSpacing spacing) → void
setDraftFontLineHeight(AppFontLineHeight height) → void
setDraftFontSize(AppFontSize size) → void
setDraftGridSize(AppGridSize size) → void
setDraftInputStyle(AppInputFieldStyle style) → void
setDraftLayoutDensity(AppLayoutDensity density) → void
setDraftLoaderColor(AppLoaderColor color) → void
setDraftLoaderType(AppLoaderType type) → void
setDraftNavigationStyle(AppNavigationStyle style) → void
setDraftPageTransition(AppPageTransition transition) → void
setDraftShadowsEnabled(bool enabled) → void
setDraftSidebarActiveColor(SidebarActiveColorOption option) → void
setDraftSidebarColor(AppSidebarColor color) → void
setDraftSidebarHoverColor(SidebarHoverColorOption option) → void
setDraftSidebarIconSize(SidebarIconSizeOption option) → void
setDraftSidebarPosition(AppSidebarPosition position) → void
setDraftSidebarTransparency(bool enabled) → void
setDraftSidebarWidth(AppSidebarWidth width) → void
setDraftTableRowHeight(AppTableRowHeight height) → void
setDraftThemeMode(AppThemeMode mode) → void
setDraftToastStyle(AppToastStyle style) → void
setDraftUiScale(AppUiScale scale) → void
setDraftUiStyle(AppUiStyle style) → void
setThemeMode(AppThemeMode mode) → void
Legacy alias kept for backward compatibility.
showLanguagePopup(BuildContext context) → void
toggleDraftPushNotifications() → void
togglePushNotifications() → void
Legacy alias kept for backward compatibility.
toggleTheme() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateLocal(Locale locale) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited