onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
ever(searchQuery, (_) => filterList());
totalPages.value = (items.length / itemsPerPage).ceil();
paginate();
}