DropdownSearch<T> class

Inheritance

Constructors

Properties

autoValidateMode AutovalidateMode?
Used to configure the auto validation of FormField and Form widgets.
finalinherited
chipProps ChipProps?
finalinherited
clickProps ClickProps
dropdown click properties
finalinherited
compareFn DropdownSearchCompareFn<T>?
function that compares two object with the same type to detected if it's the selected item or not
finalinherited
decoratorProps DropDownDecoratorProps
dropdown decoration props
finalinherited
to customize list of items UI
finalinherited
to customize list of items UI in MultiSelection mode
finalinherited
enabled bool
enable/disable dropdownSearch
finalinherited
filterFn DropdownSearchFilterFn<T>?
custom filter function
finalinherited
groupId Object?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isMultiSelectionMode bool
define whatever we are in multi selection mode or single selection mode
finalinherited
itemAsString DropdownSearchItemAsString<T>?
customize the fields the be shown
finalinherited
items DropdownSearchOnFind<T>?
items/data
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode Mode
finalinherited
onBeforeChange BeforeChange<T>?
callback executed before applying value change
finalinherited
onBeforeChangeMultiSelection BeforeChangeMultiSelection<T>?
callback executed before applying values changes
finalinherited
onBeforePopupOpening BeforePopupOpening<T>?
a callBack will be called before opening le popup if the callBack return FALSE, the opening of the popup will be cancelled
finalinherited
onBeforePopupOpeningMultiSelection BeforePopupOpeningMultiSelection<T>?
a callBack will be called before opening le popup if the callBack return FALSE, the opening of the popup will be cancelled
finalinherited
onSaved FormFieldSetter<T>?
An optional method to call with the final value when the form is saved via
finalinherited
onSavedMultiSelection FormFieldSetter<List<T>>?
An optional method to call with the final value when the form is saved via
finalinherited
onSelected ValueChanged<T?>?
called when a new item is selected
finalinherited
onSelectedMultiSelection ValueChanged<List<T>>?
called when a new items are selected
finalinherited
popupProps BasePopupProps<T>
custom popup properties
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItems List<T>
selected items
finalinherited
selectedItemsScrollProps ScrollProps?
scroll props for selected item on the dropdown. example :
finalinherited
selectedItemsWrapProps WrapProps?
finalinherited
suffixProps DropdownSuffixProps
custom suffix widget props
finalinherited
uiMode UiMode
finalinherited
validator FormFieldValidator<T>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited
validatorMultiSelection FormFieldValidator<List<T>>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() DropdownSearchState<T>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited