CustomOverlayEntry class abstract

Implementers

Constructors

CustomOverlayEntry()

Properties

completer Completer?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
overlayEntry OverlayEntry?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
getOverlayEntry(BuildContext context) OverlayEntry
getOverlayPosition(BuildContext pContext, MenuAlign? pAlign, BoxConstraints pConstraints) RelativeRect
return overlay position based on different params such, constrains, alignment and screen size
isOpen() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited