CustomMenu<T> class abstract

Implementers

Constructors

CustomMenu({required BuildContext context})

Properties

context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRoute() Route<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMenu() Future<T?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMenuPosition(BuildContext context, PositionCallback? positionCallBack, MenuAlign? align, BoxConstraints constraints, EdgeInsets? margin) RelativeRect