AdaptiveAutocompleteProps class
Constructors
- AdaptiveAutocompleteProps({AutocompleteProps materialProps = const AutocompleteProps(), CupertinoAutocompleteProps cupertinoProps = const CupertinoAutocompleteProps()})
-
const
Properties
- cupertinoProps → CupertinoAutocompleteProps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- materialProps → AutocompleteProps
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited