AutocompleteProps class

Constructors

AutocompleteProps({Object? groupId = 'DropdownSearchAutocomplete', MenuAlign? align, double? elevation = 4, ShapeBorder? shape = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(4.0))), PositionCallback? positionCallback, Clip clipBehavior = Clip.none, bool borderOnForeground = false, BorderRadiusGeometry? borderRadius, Color? shadowColor, Color? color, Color? surfaceTintColor, EdgeInsets? margin})
const

Properties

align MenuAlign?
final
borderOnForeground bool
final
borderRadius BorderRadiusGeometry?
final
clipBehavior Clip
final
color Color?
final
elevation double?
final
groupId Object?
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
final
positionCallback PositionCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
shape ShapeBorder?
final
surfaceTintColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited