AdaptiveDialogProps class
Constructors
- AdaptiveDialogProps({DialogProps materialProps = const DialogProps(), CupertinoDialogProps cupertinoProps = const CupertinoDialogProps()})
-
const
Properties
- cupertinoProps → CupertinoDialogProps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- materialProps → DialogProps
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited