DialogProps class

Constructors

DialogProps({RouteSettings? routeSettings, EdgeInsetsGeometry? iconPadding, EdgeInsetsGeometry? titlePadding, TextStyle? titleTextStyle, Widget? title, Widget? icon, bool scrollable = false, Color? iconColor, AlignmentGeometry? alignment, double? elevation, String? semanticLabel, ShapeBorder? shape, Color? barrierColor, String? barrierLabel, Color? backgroundColor, bool barrierDismissible = false, Duration transitionDuration = kThemeChangeDuration, AnimationController? animation, List<Widget>? actions, MainAxisAlignment? actionsAlignment, OverflowBarAlignment? actionsOverflowAlignment, double? actionsOverflowButtonSpacing, VerticalDirection? actionsOverflowDirection, Clip? clipBehavior = Clip.hardEdge, bool useRootNavigator = true, EdgeInsetsGeometry? actionsPadding, EdgeInsets? insetPadding, EdgeInsetsGeometry? buttonPadding, EdgeInsetsGeometry contentPadding = EdgeInsets.zero, Offset? anchorPoint, RouteTransitionsBuilder? transitionBuilder, Color? shadowColor, Color? surfaceTintColor})
const

Properties

actions List<Widget>?
final
actionsAlignment MainAxisAlignment?
final
actionsOverflowAlignment OverflowBarAlignment?
final
actionsOverflowButtonSpacing double?
final
actionsOverflowDirection VerticalDirection?
final
actionsPadding EdgeInsetsGeometry?
final
alignment AlignmentGeometry?
final
anchorPoint Offset?
final
animation AnimationController?
final
backgroundColor Color?
final
barrierColor Color?
final
barrierDismissible bool
final
barrierLabel String?
final
buttonPadding EdgeInsetsGeometry?
final
clipBehavior Clip?
final
contentPadding EdgeInsetsGeometry
final
elevation double?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
iconColor Color?
final
iconPadding EdgeInsetsGeometry?
final
insetPadding EdgeInsets?
final
routeSettings RouteSettings?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
final
semanticLabel String?
final
shadowColor Color?
final
shape ShapeBorder?
final
surfaceTintColor Color?
final
title Widget?
final
titlePadding EdgeInsetsGeometry?
final
titleTextStyle TextStyle?
final
transitionBuilder RouteTransitionsBuilder?
final
transitionDuration Duration
final
useRootNavigator bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited