MenuAlign enum

Inheritance
Available extensions

Values

bottomStart → const MenuAlign
bottomCenter → const MenuAlign
bottomEnd → const MenuAlign
topStart → const MenuAlign
topCenter → const MenuAlign
topEnd → const MenuAlign

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isDown bool

Available on MenuAlign, provided by the MenuAlignDirection extension

no setter
isUp bool

Available on MenuAlign, provided by the MenuAlignDirection extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
reverse MenuAlign

Available on MenuAlign, provided by the MenuAlignDirection extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MenuAlign>
A constant List of the values in this enum, in order of their declaration.