SuggestionsProps<T> class

Constructors

SuggestionsProps({SuggestedItemProps<T>? itemProps, SuggestionsBuilder<T>? builder, bool showSuggestions = false, SuggestedItems<T>? items})
const

Properties

builder SuggestionsBuilder<T>?
final
hashCode int
The hash code for this object.
no setterinherited
itemProps SuggestedItemProps<T>?
final
items SuggestedItems<T>?
suggested items list
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSuggestions bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited