CalibrationMachineData class

Constructors

CalibrationMachineData({int? idMachineCalibration, int? weighingMachineId, int? createdBy, int? updatedBy, String? createdOn, String? updatedOn, int? calibrationValue})
CalibrationMachineData.fromJson(Map<String, dynamic> json)

Properties

calibrationValue int?
getter/setter pair
createdBy int?
getter/setter pair
createdOn String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idMachineCalibration int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedBy int?
getter/setter pair
updatedOn String?
getter/setter pair
weighingMachineId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited