ManualGateOpenTO class

Constructors

ManualGateOpenTO({int? wbid, bool? isOpen, String? eqCode, bool? vehicalIn, String? vehicleNumber, int? vehicleId, int? loadingTypeId, int? moduleId, int? userId, bool? isManualOpen, String? remark})
ManualGateOpenTO.fromJson(Map<String, dynamic> json)
factory

Properties

eqCode String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isManualOpen bool?
getter/setter pair
isOpen bool?
getter/setter pair
loadingTypeId int?
getter/setter pair
moduleId int?
getter/setter pair
remark String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int?
getter/setter pair
vehicalIn bool?
getter/setter pair
vehicleId int?
getter/setter pair
vehicleNumber String?
getter/setter pair
wbid int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited