WeighingTO class

Constructors

WeighingTO({int? idWeighing, String? machineIp, num? measurement, DateTime? timeStamp, String? rstNo, String? wbVehicleNo, String? commodity, String? loadOrUnload, String? flag, String? material, DateTime? weighingDate, DateTime? weighingTime, String? phase, int? wbFTVehicleNoMatchRes})
WeighingTO.fromJson(Map<String, dynamic> json)
factory

Properties

commodity String?
getter/setter pair
flag String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idWeighing int?
getter/setter pair
loadOrUnload String?
getter/setter pair
machineIp String?
getter/setter pair
material String?
getter/setter pair
measurement num?
getter/setter pair
phase String?
getter/setter pair
rstNo String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStamp DateTime?
getter/setter pair
wbFTVehicleNoMatchRes int?
getter/setter pair
wbVehicleNo String?
getter/setter pair
weighingDate DateTime?
getter/setter pair
weighingTime DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited