AddonsFunDetails class

Constructors

AddonsFunDetails({int? idAddonsFunDtls, String? createdOn, int? updatedBy, String? updatedOn, String? addOnType, String? imageName, String? userDisplayName, int? createdBy, int? funRefId, String? funRefVal, int? isActive, int? isMarked, bool? isMarkedImp, int? moduleId, String? pageElementId, int? transId, String? transType})
AddonsFunDetails.fromJson(Map<String, dynamic> json)
Create object from API JSON
factory

Properties

addOnType String?
getter/setter pair
createdBy int?
getter/setter pair
createdOn String?
getter/setter pair
funRefId int?
getter/setter pair
funRefVal String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idAddonsFunDtls int?
getter/setter pair
imageName String?
getter/setter pair
isActive int?
getter/setter pair
isMarked int?
getter/setter pair
isMarkedImp bool?
getter/setter pair
moduleId int?
getter/setter pair
pageElementId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transId int?
getter/setter pair
transType String?
getter/setter pair
updatedBy int?
getter/setter pair
updatedOn String?
getter/setter pair
userDisplayName String?
getter/setter pair

Methods

copy() AddonsFunDetails
Create a deep copy of this object
copyWith({int? idAddonsFunDtls, String? createdOn, int? updatedBy, String? updatedOn, String? addOnType, String? imageName, String? userDisplayName, int? createdBy, int? funRefId, String? funRefVal, int? isActive, int? isMarked, bool? isMarkedImp, int? moduleId, String? pageElementId, int? transId, String? transType}) AddonsFunDetails
Copy object with some updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFullJson() Map<String, dynamic>
toJson() Map<String, dynamic>
Convert object to JSON for POST requests (exclude response-only fields)
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited