DownloadItem class

Constructors

DownloadItem({required String id, required String fileName, required String fileUrl, double progress = 0, DownloadStatus status = DownloadStatus.queued, String? localPath, double speedKBps = 0, double etaSeconds = 0, int downloadedBytes = 0, int totalBytes = 0, CancelToken? cancelToken, String? bgTaskId, int? downloadId, String? reportName, String? statusName, String? createdOn, String? updatedOn, bool isActive = false})
DownloadItem.fromJson(Map<String, dynamic> json)
factory

Properties

bgTaskId String?
Task ID used by background_downloader (separate from backend download ID)
getter/setter pair
cancelToken ↔ CancelToken?
getter/setter pair
createdOn String?
getter/setter pair
downloadedBytes int
getter/setter pair
downloadId int?
getter/setter pair
etaSeconds double
getter/setter pair
fileName String
getter/setter pair
fileUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
isActive bool
getter/setter pair
localPath String?
getter/setter pair
progress double
getter/setter pair
reportName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedKBps double
getter/setter pair
status DownloadStatus
getter/setter pair
statusName String?
getter/setter pair
totalBytes int
getter/setter pair
updatedOn String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromDecodedJsonList(dynamic decodedJson) List<DownloadItem>