DownloadsNotificationModel class

Constructors

DownloadsNotificationModel({String? fileName, String? fileUri, int? downloadFileId, String? status, String? errorCode, String? message})
DownloadsNotificationModel.fromJson(Map<String, dynamic> json)

Properties

downloadFileId int?
getter/setter pair
errorCode String?
getter/setter pair
fileName String?
getter/setter pair
fileUri String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited