DropDownResponse class
Constructors
- DropDownResponse({int? value, String? text, int? mappingId, int? parentId, String? secondaryText})
-
DropDownResponse.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- mappingId ↔ int?
-
getter/setter pair
- parentId ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryText ↔ String?
-
getter/setter pair
- text ↔ String?
-
getter/setter pair
- value ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromDecodedJsonList(
List jsonList) → List< DropDownResponse>