DynamicPermissionData class

Constructors

DynamicPermissionData({int? idModule, String? module, int? parentId, String? idPermission})
DynamicPermissionData.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
idModule int?
getter/setter pair
idPermission String?
getter/setter pair
module String?
getter/setter pair
parentId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited