EventsResponse class

Constructors

EventsResponse({int? idPerson, int? salutationId, String? mobileNo, String? alternateMobNo, String? phoneNo, int? createdBy, String? dateOfBirth, String? createdOn, String? firstName, String? midName, String? lastName, String? primaryEmail, String? alternateEmail, String? comments, String? salutationName, String? dateOfBirthStr, int? dobDay, int? dobMonth, int? dobYear, int? anniDay, int? anniMonth, int? anniYear, String? dateOfAnniversary, int? otherDesignationId, int? idOrganization, String? firmName, String? personType, int? idPersonType, int? idRole})
EventsResponse.fromJson(Map<String, dynamic> json)

Properties

alternateEmail String?
getter/setter pair
alternateMobNo String?
getter/setter pair
anniDay int?
getter/setter pair
anniMonth int?
getter/setter pair
anniYear int?
getter/setter pair
comments String?
getter/setter pair
createdBy int?
getter/setter pair
createdOn String?
getter/setter pair
dateOfAnniversary String?
getter/setter pair
dateOfBirth String?
getter/setter pair
dateOfBirthStr String?
getter/setter pair
dobDay int?
getter/setter pair
dobMonth int?
getter/setter pair
dobYear int?
getter/setter pair
firmName String?
getter/setter pair
firstName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idOrganization int?
getter/setter pair
idPerson int?
getter/setter pair
idPersonType int?
getter/setter pair
idRole int?
getter/setter pair
lastName String?
getter/setter pair
midName String?
getter/setter pair
mobileNo String?
getter/setter pair
otherDesignationId int?
getter/setter pair
personType String?
getter/setter pair
phoneNo String?
getter/setter pair
primaryEmail String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salutationId int?
getter/setter pair
salutationName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromDecodedJsonList(List jsonList) List<EventsResponse>