LoginNewResponse class

Inheritance

Constructors

LoginNewResponse({String? status, int? statusCode, String? message, LoginModel? data})
LoginNewResponse.fromJson(Map<String, dynamic> json)
factory

Properties

data LoginModel?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pairinherited
statusCode int?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited