LoginTO class

Constructors

LoginTO({int? idLogin, int? userId, String? loginDate, String? logoutDate, String? loginIP, String? latitude, String? longitude, String? browserName, String? platformDetails})
LoginTO.fromJson(Map<String, dynamic> json)

Properties

browserName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idLogin int?
getter/setter pair
latitude String?
getter/setter pair
loginDate String?
getter/setter pair
loginIP String?
getter/setter pair
logoutDate String?
getter/setter pair
longitude String?
getter/setter pair
platformDetails String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited