Tag class

Constructors

Tag({int? idUser, int? userTypeId, int? isActive, String? userLogin, String? userPasswd, int? personId, int? addressId, int? organizationId, String? organizationName, int? totalCount, int? wishlistCount, int? rowNumber, List<UserRoleList>? userRoleList, LoginTO? loginTO, String? userDisplayName, String? registeredDeviceId, int? isSpecialCnf, UserPersonTO? userPersonTO, String? deactivatedOn, int? deactivatedBy, String? imeiNumber, int? firmNameE, bool? isSetDeviceId, int? orgStructId, int? levelId, int? reportingTo, int? userReportingId, String? path, int? doucmentId, int? isChangeModeUser, int? loginTypeID, int? isProFlowUser})
Tag.fromJson(Map<String, dynamic> json)

Properties

addressId int?
getter/setter pair
deactivatedBy int?
getter/setter pair
deactivatedOn String?
getter/setter pair
doucmentId int?
getter/setter pair
firmNameE int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idUser int?
getter/setter pair
imeiNumber String?
getter/setter pair
isActive int?
getter/setter pair
isChangeModeUser int?
getter/setter pair
isProFlowUser int?
getter/setter pair
isSetDeviceId bool?
getter/setter pair
isSpecialCnf int?
getter/setter pair
levelId int?
getter/setter pair
loginTO LoginTO?
getter/setter pair
loginTypeID int?
getter/setter pair
organizationId int?
getter/setter pair
organizationName String?
getter/setter pair
orgStructId int?
getter/setter pair
path String?
getter/setter pair
personId int?
getter/setter pair
registeredDeviceId String?
getter/setter pair
reportingTo int?
getter/setter pair
rowNumber int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int?
getter/setter pair
userDisplayName String?
getter/setter pair
userLogin String?
getter/setter pair
userPasswd String?
getter/setter pair
userPersonTO UserPersonTO?
getter/setter pair
userReportingId int?
getter/setter pair
userRoleList List<UserRoleList>?
getter/setter pair
userTypeId int?
getter/setter pair
wishlistCount int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited