UserPersonTO class

Constructors

UserPersonTO({int? idPerson, int? userTypeId, int? isUserCreate, int? isActive, int? orgTypeId, int? salutationId, String? mobileNo, String? alternateMobNo, String? phoneNo, int? createdBy, String? dateOfBirth, String? createdOn, String? firstName, String? midName, String? lastName, String? primaryEmail, String? alternateEmail, String? comments, int? seqNo, int? organizationId, int? personTypeId, int? isDefault1, int? isDefault2, int? delPeriodId, int? cdStructureId, String? salutationName, String? dateOfBirthStr, int? dobDay, int? dobMonth, int? dobYear, String? dateOfAnniversary, int? otherDesignationId, String? multiroleDesc, int? userId, int? userIsActive})
UserPersonTO.fromJson(Map<String, dynamic> json)

Properties

alternateEmail String?
getter/setter pair
alternateMobNo String?
getter/setter pair
cdStructureId int?
getter/setter pair
comments String?
getter/setter pair
createdBy int?
getter/setter pair
createdOn String?
getter/setter pair
dateOfAnniversary String?
getter/setter pair
dateOfBirth String?
getter/setter pair
dateOfBirthStr String?
getter/setter pair
delPeriodId int?
getter/setter pair
dobDay int?
getter/setter pair
dobMonth int?
getter/setter pair
dobYear int?
getter/setter pair
firstName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idPerson int?
getter/setter pair
isActive int?
getter/setter pair
isDefault1 int?
getter/setter pair
isDefault2 int?
getter/setter pair
isUserCreate int?
getter/setter pair
lastName String?
getter/setter pair
midName String?
getter/setter pair
mobileNo String?
getter/setter pair
multiroleDesc String?
getter/setter pair
organizationId int?
getter/setter pair
orgTypeId int?
getter/setter pair
otherDesignationId int?
getter/setter pair
personTypeId int?
getter/setter pair
phoneNo String?
getter/setter pair
primaryEmail String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salutationId int?
getter/setter pair
salutationName String?
getter/setter pair
seqNo int?
getter/setter pair
userId int?
getter/setter pair
userIsActive int?
getter/setter pair
userTypeId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited