UserRoleList class

Constructors

UserRoleList({int? idUserRole, int? userId, int? roleId, int? isActive, int? createdBy, String? createdOn, String? roleDesc, int? enableAreaAlloc, int? roleTypeId})
UserRoleList.fromJson(Map<String, dynamic> json)

Properties

createdBy int?
getter/setter pair
createdOn String?
getter/setter pair
enableAreaAlloc int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idUserRole int?
getter/setter pair
isActive int?
getter/setter pair
roleDesc String?
getter/setter pair
roleId int?
getter/setter pair
roleTypeId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited