NotificationsResponse class

Constructors

NotificationsResponse({int? idAlertUser, int? alertInstanceId, int? userId, int? roleId, String? raisedByUserName, String? alertComment, String? raisedOn, String? raisedOnStr, int? isAcknowledged, int? isReseted, int? alertDefinitionId, String? navigationUrl, int? sourceEntityId, int? moduleId, int? isLogOut, String? snoozeDate, int? snoozeCount, int? isSendSrcId})
NotificationsResponse.fromJson(Map<String, dynamic> json)

Properties

alertComment String?
getter/setter pair
alertDefinitionId int?
getter/setter pair
alertInstanceId int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idAlertUser int?
getter/setter pair
isAcknowledged int?
getter/setter pair
isLogOut int?
getter/setter pair
isReseted int?
getter/setter pair
isSendSrcId int?
getter/setter pair
moduleId int?
getter/setter pair
getter/setter pair
raisedByUserName String?
getter/setter pair
raisedOn String?
getter/setter pair
raisedOnStr String?
getter/setter pair
roleId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snoozeCount int?
getter/setter pair
snoozeDate String?
getter/setter pair
sourceEntityId int?
getter/setter pair
userId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromDecodedJsonList(List jsonList) List<NotificationsResponse>