OrganizationHierarchyData class

Constructors

OrganizationHierarchyData({String? nameAclPositionMapping, int? idAclPositionMapping, int? idOrganization, int? idDivision, int? idDepartment, int? idSubDepartment, int? idRole, int? idUser})
OrganizationHierarchyData.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
idAclPositionMapping int?
getter/setter pair
idDepartment int?
getter/setter pair
idDivision int?
getter/setter pair
idOrganization int?
getter/setter pair
idRole int?
getter/setter pair
idSubDepartment int?
getter/setter pair
idUser int?
getter/setter pair
nameAclPositionMapping String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited