PermissionData class

Constructors

PermissionData({int? idDataMapping, int? idDivision, String? division, int? idDepartment, String? department, int? idRole, String? role, int? idModule, String? module, int? idUser, int? idPermission, String? permission})
PermissionData.fromJson(Map<String, dynamic> json)

Properties

department String?
getter/setter pair
division String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idDataMapping int?
getter/setter pair
idDepartment int?
getter/setter pair
idDivision int?
getter/setter pair
idModule int?
getter/setter pair
idPermission int?
getter/setter pair
idRole int?
getter/setter pair
idUser int?
getter/setter pair
module String?
getter/setter pair
permission String?
getter/setter pair
role String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited