PermissionMapping class

Constructors

PermissionMapping({int? idDataMapping, int? idDivision, int? idDepartment, int? idRole, int? idModule, int? idUser, int? idPermission, String? type, bool hasChanged = false})
PermissionMapping.fromJson(Map<String, dynamic> json)

Properties

hasChanged bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idDataMapping int?
getter/setter pair
idDepartment int?
getter/setter pair
idDivision int?
getter/setter pair
idModule int?
getter/setter pair
idPermission int?
getter/setter pair
idRole int?
getter/setter pair
idUser int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair

Methods

copyWith() PermissionMapping
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited