UnifiedAddressResponse class

Constructors

UnifiedAddressResponse({required String name, String? gstNo, String? panNo, String? aadharNo, String? address, String? village, String? taluka, String? district, String? pinCode, String? contactNo, DropDownResponse? stateDropDown})

Properties

aadharNo String?
final
address String?
final
contactNo String?
final
district String?
final
gstNo String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
panNo String?
final
pinCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateDropDown DropDownResponse?
final
taluka String?
final
village String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited