ImageDetails class

Constructors

ImageDetails({int? createdBy, String? documentDesc, String? extension, String? fileData, int? fileTypeId, String? moduleId, bool? isNeedToUpload})
ImageDetails.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy int?
getter/setter pair
documentDesc String?
getter/setter pair
extension String?
getter/setter pair
fileData String?
getter/setter pair
fileTypeId int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isNeedToUpload bool?
getter/setter pair
moduleId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited