$AssetsFontsGen class

Constructors

$AssetsFontsGen()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
poppinsBold String
File path: assets/fonts/Poppins-Bold.ttf
no setter
poppinsItalic String
File path: assets/fonts/Poppins-Italic.ttf
no setter
poppinsRegular String
File path: assets/fonts/Poppins-Regular.ttf
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited