$AssetsImagesGen class
Constructors
- $AssetsImagesGen()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- polaadLogo → AssetGenImage
-
File path: assets/images/polaad_logo.png
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simpliworksLogo → AssetGenImage
-
File path: assets/images/simpliworks_logo.png
no setter
- simpliworksLogoWhite → AssetGenImage
-
File path: assets/images/simpliworks_logo_white.png
no setter
- syncfusionLogo → AssetGenImage
-
File path: assets/images/syncfusion_logo.jpg
no setter
-
values
→ List<
AssetGenImage> -
List of all assets
no setter
- weserveLogoWhite → AssetGenImage
-
File path: assets/images/weserve_logo_white.png
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited