$AssetsMapsGen class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
india
→ String
-
File path: assets/maps/india.json
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<String>
-
List of all assets
no setter
-
worldMap
→ String
-
File path: assets/maps/world_map.json
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited