UiLog class

Constructors

UiLog({required String id, required String screen, required int loadTimeMs, int frameDrops = 0, bool memoryWarning = false, required String platform, required DateTime timestamp})
UiLog.fromJson(String source)
factory
UiLog.fromMap(Map map)
factory

Properties

frameDrops int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
loadTimeMs int
final
memoryWarning bool
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited