MonitorDashboardController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • MonitorDashboardController
Implemented types

Properties

activeTab → RxInt
final
apiCurrentPage → RxInt
final
apiPageSize → RxInt
final
averageLatency double
no setter
averageUiLoadTime double
no setter
clientFailuresCount int
no setter
connectionFailuresCount int
no setter
crashLogs List<ApiLog>
no setter
filteredApiLogs List<ApiLog>
no setter
filteredUiLogs List<UiLog>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isAuthorized → RxBool
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onlyFailures → RxBool
final
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
paginatedApiLogs List<ApiLog>
no setter
paginatedUiLogs List<UiLog>
no setter
passcodeError → RxString
final
rawApiLogs → RxList<ApiLog>
final
rawUiLogs → RxList<UiLog>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery → RxString
final
selectedDate → Rxn<DateTime>
final
selectedMethod → RxString
final
selectedPlatform → RxString
final
serializationFailuresCount int
no setter
serverFailuresCount int
no setter
shouldCrashSubWidget → RxBool
final
successRate double
no setter
totalApiPages int
no setter
totalRequests int
no setter
totalUiPages int
no setter
uiCurrentPage → RxInt
final
uiPageSize → RxInt
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
authorize(String inputPasscode) → void
clearLogs() Future<void>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
exportAll() Future<void>
loadLogs() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited