ApiService class

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteData(String endpoint, {dynamic data, Map<String, dynamic>? queryParams}) Future<Response>
DELETE request
getData(String endpoint, {Map<String, dynamic>? queryParams}) Future<Response>
getDataFullUrl(String fullUrl, {dynamic data, Map<String, dynamic>? queryParams, Map<String, String>? headers}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postData(String endpoint, {dynamic data, Map<String, dynamic>? queryParams, CancelToken? cancelToken}) Future<Response>
POST request
postDataFullUrl(String fullUrl, {dynamic data, Map<String, dynamic>? queryParams, Map<String, String>? headers}) Future<Response>
putData(String endpoint, {dynamic data, Map<String, dynamic>? queryParams}) Future<Response>
PUT request
toString() String
A string representation of this object.
inherited
uploadFile(String endpoint, {required File file, String? fileKey = 'file', Map<String, dynamic>? additionalData}) Future<Map<String, dynamic>>
Multipart (File Upload) request
uploadFileList(List<Uint8List> fileBytesList, List<String> fileNames, Map<String, dynamic>? queryParams) Future<Response>
uploadImageList(List? files, List<Uint8List> fileBytesList, {required int createdBy, required int fileTypeId, required int moduleId}) Future<Response>

Operators

operator ==(Object other) bool
The equality operator.
inherited