ApiClient class

Constructors

ApiClient(String initialBaseUrl)

Properties

client → Dio
no setter
currentBaseUrl String
no setter
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionController SessionController
final
storageUtils StorageUtils
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBaseUrl() → void
toString() String
A string representation of this object.
inherited
updateBaseUrl(String baseUrl) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited