CommonRoutes class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- attributeScreen → const String
- crmDashboardScreen → const String
- deliverDashboardScreen → const String
- expenseDashboardScreen → const String
- financeDashboardScreen → const String
- home → const String
- initial → const String
- login → const String
- manageItemScreen → const String
- manageUser → const String
- masterDashboardScreen → const String
- masterScreen → const String
- notFoundScreen → const String
- permissions → const String
- preferences → const String
- recyclerDashboardScreen → const String
- storeDashboardScreen → const String
- storeScreen → const String
- userManagementScreen → const String