WebRoutes class

Constructors

WebRoutes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

routes List<GetPage>
final

Constants

attributeScreen → const String
initial → const String
login → const String
manageItemScreen → const String
manageUser → const String
masterScreen → const String
notFoundScreen → const String
permissions → const String
preferences → const String
storeScreen → const String
userManagementScreen → const String