DownloadRepository class

Constructors

DownloadRepository()

Properties

apiClient ApiClient
final
apiService ApiService
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDownload({required String name, required String url, required String httpMethod, required String moduleName, required String payload}) Future<DownloadResponse>
getDownloads() Future<List<DownloadItem>>
MOCK LIST
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryDownload(String id) Future<void>
Changes Download Status from 'Ready to Download' to 'Downloaded' when user downloads the file in local system
toString() String
A string representation of this object.
inherited
updateDownloadStatus(String id) Future<void>
Changes Download Status from 'Ready to Download' to 'Downloaded' when user downloads the file in local system

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isSameDateAsToday(String? date) bool