DownloadService class abstract

Implementers

Constructors

DownloadService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(DownloadItem item) Future<void>
downloadFile({required DownloadItem item, required dynamic onProgress(int, int)}) Future<void>
initialize(void callback(String id, int status, int progress)) Future<void>
loadPersistedTasks() Future<List<DownloadItem>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFile(DownloadItem item) Future<void>
pause(DownloadItem item) Future<void>
resume(DownloadItem item) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited