LocationService class

Constructors

LocationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageUtils StorageUtils
final

Methods

clearStoredLocation() Future<void>
getStoredLatitude() double?
getStoredLongitude() double?
hasStoredLocation() bool
initLocation(BuildContext context) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshLocation(BuildContext context) Future<Position?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

gpsTimeout → const Duration
maxAllowedAccuracy → const double