LoginViewWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LoginViewWidget
Constructors
- LoginViewWidget({Key? key, required bool isMobile, required double height, required double width})
Properties
- appConfigService → AppConfigService
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- isMobile → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locationController → LocationController
-
final
- loginController → LoginController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildEmail(
) → Widget -
buildHeader(
BuildContext context) → Widget -
buildLoader(
) → Widget -
buildLoginForm(
BuildContext context) → Widget -
buildLoginMobile(
BuildContext context) → Widget -
buildLoginWeb(
BuildContext context) → Widget -
buildLogo(
) → Widget -
buildPassword(
) → Widget -
buildShowVersion(
) → Widget -
buildSignInButton(
BuildContext context) → Widget -
buildView(
BuildContext context) → Widget -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
loginAPI(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited