UploadContext class

Constructors

UploadContext({required int moduleId, required String transType, required int transId, required String pageElementPrefix, required int createdBy, required int fileTypeId})

Properties

createdBy int
final
fileTypeId int
final
hashCode int
The hash code for this object.
no setterinherited
moduleId int
final
pageElementPrefix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transId int
final
transType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageElementId(int rowSequence) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited