AppConstants class

Constructors

AppConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accentColorKey → const String
aclPositionMappingIdKey → const String
aclPositionMappingNameKey → const String
actionButtonColorKey → const String
actionButtonShapeKey → const String
actionButtonStyleKey → const String
animationsEnabledKey → const String
appBarHeightKey → const String
appBarShadowKey → const String
appBarStyleKey → const String
appBarTitleAlignmentKey → const String
borderRadiusKey → const String
buttonStyleKey → const String
cardElevationKey → const String
clientLogoUrl → const String
cnfOrgIdKey → const String
contentWidthKey → const String
customAccentColorKey → const String
customLoaderColorKey → const String
customSidebarColorKey → const String
customSidebarTextColorKey → const String
dashboardGridSizeKey → const String
dataGridTemplateKey → const String
departmentIdKey → const String
divisionIdKey → const String
firstTimeLoginKey → const String
fontFamilyKey → const String
fontLetterSpacingKey → const String
fontLineHeightKey → const String
fontSizeKey → const String
inputStyleKey → const String
isDarkModeKey → const String
isLoggedInKey → const String
itemsKey → const String
latitudeKey → const String
layoutDensityKey → const String
loaderColorKey → const String
loaderTypeKey → const String
localeKey → const String
locationPermission → const String
loggedInPassword → const String
loggedInUserName → const String
longitudeKey → const String
masterRoleTypeIdKey → const String
notificationPermission → const String
organizationIdKey → const String
pageTransitionKey → const String
profileKey → const String
pushNotificationsKey → const String
roleIdKey → const String
shadowsEnabledKey → const String
sidebarActiveColorKey → const String
sidebarColorKey → const String
sidebarHoverColorKey → const String
sidebarIconSizeKey → const String
sidebarPositionKey → const String
sidebarTransparencyKey → const String
sidebarWidthKey → const String
tableRowHeightKey → const String
themeModeKey → const String
toastStyleKey → const String
tokenKey → const String
uiScaleKey → const String
uiStyleKey → const String
userDepartments → const String
userIdKey → const String
userName → const String
userRoles → const String