AppThemeMode enum

Three-way theme preference: light, dark, or follow system.

Inheritance
Available extensions

Values

light → const AppThemeMode
dark → const AppThemeMode
system → const AppThemeMode

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppThemeMode>
A constant List of the values in this enum, in order of their declaration.