AppUtils class

Constructors

AppUtils()

Properties

darkPalette List<Color>
getter/setter pair
darkPaletteOld List<Color>
final
hashCode int
The hash code for this object.
no setterinherited
lightPalette List<Color>
getter/setter pair
lightPaletteOld List<Color>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

clientLogoUrls Map<int, String>
getter/setter pair

Static Methods

formatDateTime(DateTime dateTime) String
formatINR(dynamic amount, {bool showDecimals = false}) String
getAppVersion() Future<String>
getDataGridRowColor(int rowIndex) Color
getDynamicClientLogoUrl(int clientType) String
hideKeyboard() → void
showActionBottomSheet(BuildContext context, Widget content, {bool isScrollControlled = false}) → void
showDialog({required BuildContext context, required String title, Widget? content, String? middleText, VoidCallback? onConfirm, VoidCallback? onCancel, String confirmText = 'OK', String? cancelText, Color confirmTextColor = Colors.white, Color cancelTextColor = Colors.black, Color buttonColor = AppColors.blue}) → void
showDialogPopUp({required String headerName, required String content, required String buttonText}) → dynamic
showSnackBar(String message, {Color? background, String? title, SnackPosition? position}) → void