AppColors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- dataGridGreen ↔ Color
-
getter/setter pair
- dataGridRed ↔ Color
-
getter/setter pair
- dataGridYellow ↔ Color
-
getter/setter pair
Constants
- background → const Color
- blue → const Color
- contentColorBlue → const Color
- contentColorCyan → const Color
- darkAppBarBackground → const Color
- darkButtonColor → const Color
- darkCardColor → const Color
- darkDrawerBackgroundColor → const Color
- darkIconThemeColor → const Color
- darkPrimary → const Color
- darkPrimaryColorDark → const Color
- darkScaffoldBackgroundColor → const Color
- darkSurface → const Color
- darkTitleTextColor → const Color
- dataGridBlue → const Color
- dataGridGrey → const Color
- dividerColors → const Color
- error → const Color
- lightAppBarBackground → const Color
- lightButtonColor → const Color
- lightCardColor → const Color
- lightDrawerBackgroundColor → const Color
- lightIconThemeColor → const Color
- lightPrimary → const Color
- lightPrimaryColorDark → const Color
- lightScaffoldBackgroundColor → const Color
- lightSurface → const Color
- lightTitleTextColor → const Color
- mainGridLineColor → const Color
- onBackground → const Color
- onDrawerBackground → const Color
- onError → const Color
- onPrimary → const Color
- onSecondary → const Color
- onSurface → const Color
- primary → const Color
- primaryColor → const Color
- primaryVariant → const Color
- secondary → const Color
- secondaryVariant → const Color
- success → const Color
- surface → const Color
- textFieldBackgroundColor → const Color
- viewBackgroundColor → const Color