AppGradients class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
allGradients
→ List<
LinearGradient> -
final
- length → int
-
no setter
Static Methods
-
getByIndex(
int index) → LinearGradient
Constants
- aquaBlueToSkyBlue → const LinearGradient
- aquaMarine → const LinearGradient
- blushPinkToPeach → const LinearGradient
- cherryBlossom → const LinearGradient
- cyanToBrightBlue → const LinearGradient
- deepBlueToPurple → const LinearGradient
- deepSeaBlue → const LinearGradient
- deepTealToAqua → const LinearGradient
- emeraldToTealBlue → const LinearGradient
- frostBlue → const LinearGradient
- goldToOrange → const LinearGradient
- icyBlueToAzure → const LinearGradient
- juicyPeach → const LinearGradient
- lavenderToVividPurple → const LinearGradient
- lightBlueToRoyalBlue → const LinearGradient
- lilacToBlueberry → const LinearGradient
- limeGreenToForestGreen → const LinearGradient
- mintGreenToEmerald → const LinearGradient
- nightFade → const LinearGradient
- orangePeachToCoralRed → const LinearGradient
- periwinkleToIndigo → const LinearGradient
- purpleToPink → const LinearGradient
- rosePinkToLavender → const LinearGradient
- royalBlueToDeepBlue → const LinearGradient
- royalBlueToViolet → const LinearGradient
- royalGarden → const LinearGradient
- skyBlueToSteelBlue → const LinearGradient
- sunnyMorning → const LinearGradient
- sunsetOrangeToPink → const LinearGradient
- tealGreenToLavender → const LinearGradient
- warmFlame → const LinearGradient
- winterNeva → const LinearGradient