ColumnWidthResolver class

Constructors

ColumnWidthResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolveMinWidth(String columnName, {TextStyle? headerStyle, double paddingHorizontal = 24.0, double sortIconWidth = 20.0, double minFloor = 100.0, double maxCap = 320.0}) double
Computes the minimum column width needed to display columnName without truncation, including padding and sort-icon allowance.