ResponsiveColumnSizer class
Properties
-
context
→ BuildContext
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
final
-
iconsOuterPadding
↔ EdgeInsetsGeometry
-
Defines the outer padding of the sort and filter icon's container. We need
to consider this padding to measure the auto-width and height calculation.
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeCellHeight(GridColumn column, DataGridRow row, Object? cellValue, TextStyle textStyle)
→ double
-
Calculates the height of the cell based on the
DataGridCell.value.
You can override this method to perform the custom calculation for hight.
inherited
-
computeCellWidth(GridColumn column, DataGridRow row, Object? cellValue, TextStyle textStyle)
→ double
-
Calculates the width of the cell based on the
DataGridCell.value. You
can override this method to perform the custom calculation for width.
-
Calculates the height of the header cell based on the
GridColumn.columnName.
inherited
-
Calculates the width of the header cell based on the
GridColumn.columnName.
You can override this method to perform the custom calculation for height.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited