ResponsiveUtils class

Constructors

ResponsiveUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

columnWidthMode(BuildContext context) → ColumnWidthMode
Best ColumnWidthMode for the current screen width.
frozenColumns(BuildContext context, {int requested = 0}) int
How many columns to freeze on the left on small screens.
horizontalPhysics(BuildContext context) ScrollPhysics
Adaptive horizontal scroll physics per platform.
isDesktop(BuildContext context) bool
isMobile(BuildContext context) bool
isTablet(BuildContext context) bool
resolve<T>(BuildContext context, {required T mobile, required T tablet, required T desktop}) → T
Returns a value based on the current screen size.