frozenColumns static method
How many columns to freeze on the left on small screens.
Implementation
static int frozenColumns(BuildContext context, {int requested = 0}) {
if (isMobile(context) && requested == 0) return 1;
return requested;
}
How many columns to freeze on the left on small screens.
static int frozenColumns(BuildContext context, {int requested = 0}) {
if (isMobile(context) && requested == 0) return 1;
return requested;
}