AppDateUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatDate(
String dateTimeStr) → String -
formatDateWithTime(
String dateTimeStr) → String -
formatTime(
String timeStr) → String -
formatTimeWithAmPm(
DateTime time) → String -
fromTimestamp(
int timestamp) → DateTime -
getCurrentDate(
) → String -
getDayOfWeek(
DateTime date) → String -
getMonthName(
DateTime date) → String -
parseDate(
String dateString, String format) → DateTime -
removeTime(
DateTime date) → DateTime -
toCompactYearMonthDay(
DateTime date) → String -
toDayMonthYear(
DateTime date) → String -
toDayMonthYearDash(
DateTime date) → String -
toMonthDayYear(
DateTime date) → String -
toTime(
DateTime date) → String -
toTimeHourMinute(
DateTime date) → String -
toTimestamp(
DateTime date) → int -
toYearMonthDay(
DateTime date) → String