AppTableRowHeight enum
Values
- short → const AppTableRowHeight
-
const AppTableRowHeight('Short (36px)', 36.0) - medium → const AppTableRowHeight
-
const AppTableRowHeight('Medium (48px)', 48.0) - tall → const AppTableRowHeight
-
const AppTableRowHeight('Tall (60px)', 60.0) - auto → const AppTableRowHeight
-
const AppTableRowHeight('Auto Adjust', double.nan)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppTableRowHeight> - A constant List of the values in this enum, in order of their declaration.