AppToastStyle enum

Inheritance
Available extensions

Values

minimal → const AppToastStyle
const AppToastStyle('Minimal (Left Accent Line)')
fillColor → const AppToastStyle
const AppToastStyle('Fill Color (Solid Background)')
flat → const AppToastStyle
const AppToastStyle('Flat (Border & Subtle Accent)')
flatColored → const AppToastStyle
const AppToastStyle('Flat Colored (Accent Tinted Flat)')
simple → const AppToastStyle
const AppToastStyle('Simple (Clean Minimal)')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppToastStyle>
A constant List of the values in this enum, in order of their declaration.