AppUiScale enum
Values
- scale80 → const AppUiScale
-
const AppUiScale('80% (Compact)', 0.8) - scale90 → const AppUiScale
-
const AppUiScale('90%', 0.9) - scale100 → const AppUiScale
-
const AppUiScale('100% (Default)', 1.0) - scale110 → const AppUiScale
-
const AppUiScale('110%', 1.1) - scale120 → const AppUiScale
-
const AppUiScale('120% (Comfortable)', 1.2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppUiScale> - A constant List of the values in this enum, in order of their declaration.