ClientsEnum enum
Values
- BRM → const ClientsEnum
-
const ClientsEnum(1) - SRJ → const ClientsEnum
-
const ClientsEnum(2) - GANARAJ → const ClientsEnum
-
const ClientsEnum(3) - PARMESHWAR → const ClientsEnum
-
const ClientsEnum(4) - BHULESHWAR → const ClientsEnum
-
const ClientsEnum(5) - VASUDHA → const ClientsEnum
-
const ClientsEnum(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ClientsEnum> - A constant List of the values in this enum, in order of their declaration.