ModulesEnum enum
Values
- MAIN → const ModulesEnum
-
const ModulesEnum(0) - CRM → const ModulesEnum
-
const ModulesEnum(1) - DELIVER → const ModulesEnum
-
const ModulesEnum(2) - SCHEDULE → const ModulesEnum
-
const ModulesEnum(3) - RESOLVE → const ModulesEnum
-
const ModulesEnum(4) - RECYCLE → const ModulesEnum
-
const ModulesEnum(5) - ENQUIRY → const ModulesEnum
-
const ModulesEnum(6) - EXPENSE → const ModulesEnum
-
const ModulesEnum(7) - STORE → const ModulesEnum
-
const ModulesEnum(8) - SETTINGS → const ModulesEnum
-
const ModulesEnum(9) - FINANCE → const ModulesEnum
-
const ModulesEnum(10) - INTERNALTRANSFER → const ModulesEnum
-
const ModulesEnum(11)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ModulesEnum> - A constant List of the values in this enum, in order of their declaration.