AllAppsDrawer class

Inheritance

Constructors

AllAppsDrawer({Key? key})

Properties

backgroundColor Color?
Sets the color of the Material that holds all of the Drawer's contents.
finalinherited
child Widget?
The widget below this widget in the tree.
finalinherited
clipBehavior Clip?
The content will be clipped (or not) according to this option.
finalinherited
elevation double?
The z-coordinate at which to place this drawer relative to its parent.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
homeController HomeController
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
The semantic label of the drawer used by accessibility frameworks to announce screen transitions when the drawer is opened and closed.
finalinherited
shadowColor Color?
The color used to paint a drop shadow under the drawer's Material, which reflects the drawer's elevation.
finalinherited
shape ShapeBorder?
The shape of the drawer.
finalinherited
surfaceTintColor Color?
The color used as a surface tint overlay on the drawer's background color, which reflects the drawer's elevation.
finalinherited
width double?
The width of the drawer.
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildItem(Product value, BuildContext context) Widget
buildSearch() Widget
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited