AppTextFieldFormWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AppTextFieldFormWidget
Constructors
-
AppTextFieldFormWidget({Key? key, double? height = 40.0, double? width, String hint = '', TextInputType keyboardType = TextInputType.text, int? maxLength, double? fontSize = 13.0, FontWeight? fontWeight = FontWeight.normal, Color? textColor, List<
TextInputFormatter> ? inputFormatters, TapRegionCallback? onTapOutside, TapRegionUpCallback? onTapUpOutside, String? customValidator(String?)?, TextEditingController? controller, String? initialValue, int? maxLines = 1, int? minLines, bool autofocus = false, TextInputAction? textInputAction, bool isValidator = false, bool enabled = true, ValueChanged<String> ? onChanged, ValueChanged<String> ? onSubmitted, VoidCallback? onEditingComplete, String? validationMessage, Iterable<String> ? autofillHints, bool autoCorrect = false, FocusNode? focusNode, bool? showPasswordType = false, Widget? suffixIcon, Color? backgroundColor, void onTap()?, bool isSearch = false, AutovalidateMode? autovalidateMode}) -
const
Properties
- autoCorrect → bool
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- autovalidateMode → AutovalidateMode?
-
final
- backgroundColor → Color?
-
final
- controller → TextEditingController?
-
final
- customValidator → String? Function(String?)?
-
final
- enabled → bool
-
final
- focusNode → FocusNode?
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- hint → String
-
final
- initialValue → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isSearch → bool
-
final
- isValidator → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onEditingComplete → VoidCallback?
-
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- onTap → void Function()?
-
final
- onTapOutside → TapRegionCallback?
-
final
- onTapUpOutside → TapRegionUpCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPasswordType → bool?
-
final
- suffixIcon → Widget?
-
final
- textColor → Color?
-
final
- textInputAction → TextInputAction?
-
final
- validationMessage → String?
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AppTextFieldFormWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited