AppDropDownWithMultiSelection class

Inheritance
Available extensions

Constructors

AppDropDownWithMultiSelection({Key? key, double? width, required Rxn<List<DropDownResponse>> selectedValues, required String hintText, required VoidCallback onShowDialogBox, required VoidCallback onClearPressed, dynamic onItemsChanged(List<DropDownResponse>)?, bool isValidator = false, String? validator(String?)?, RxList<DropDownResponse>? listItems})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hintText String
final
isValidator bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listItems → RxList<DropDownResponse>?
final
onClearPressed → void Function()
final
onItemsChanged → dynamic Function(List<DropDownResponse>)?
final
onShowDialogBox → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValues → Rxn<List<DropDownResponse>>
final
validator String? Function(String?)?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
center() Widget

Available on Widget, provided by the WidgetExtension extension

createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded([int flex = 1]) Widget

Available on Widget, provided by the WidgetExtension extension

getSelectedValue(int id) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double value) Widget

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible) Widget

Available on Widget, provided by the WidgetExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited