Header class

Inheritance
Implemented types

Constructors

Header({Key? key, List<Widget>? actions, PreferredSizeWidget? bottom, String title = 'simpliWORKS™', bool centerTitle = true, bool showAllApps = false, bool automaticallyImplyLeading = true, PopupMenuItemSelected<String>? onSelected, VoidCallback? onHomeCallback, Widget? leading, Widget? headerLogoAsset})

Properties

actions List<Widget>?
final
appConfigService AppConfigService
final
automaticallyImplyLeading bool
final
bottom PreferredSizeWidget?
final
centerTitle bool
final
hashCode int
The hash code for this object.
no setterinherited
headerLogoAsset Widget?
final
homeController HomeController
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
final
modulesName Map<int, String>
getter/setter pair
onHomeCallback VoidCallback?
final
onSelected PopupMenuItemSelected<String>?
final
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAllApps bool
final
storageUtils StorageUtils
final
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildMobileHeader(BuildContext context) Widget
buildModule(BuildContext context, String moduleName) Widget
buildModuleName(dynamic context, dynamic moduleType) Widget
buildUserProfile(BuildContext context) Widget
buildWebHeader(BuildContext context) Widget
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDynamicModulesName(int moduleType) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited