loadListingIfNeeded method
Implementation
Future<void> loadListingIfNeeded() async {
// This method can be used to trigger any data loading when the home screen is accessed.
// For example, you could call fetchHomePermission() here if you want to refresh permissions every time.
await fetchHomePermission();
}