refreshDraftsFromStorage method
void
refreshDraftsFromStorage()
Call this when the Preferences screen is opened to ensure drafts always start from the latest persisted state.
Implementation
void refreshDraftsFromStorage() {
_loadPersistedPreferences();
}