CupertinoCustomOverlyEntry class
- Inheritance
-
- Object
- CustomOverlayEntry
- CupertinoCustomOverlyEntry
Constructors
- CupertinoCustomOverlyEntry({required CupertinoAutocompleteProps props, required BoxConstraints constraints, Widget? child, TapRegionCallback? onTapOutside})
Properties
- child → Widget?
-
final
- completer ↔ Completer?
-
getter/setter pairinherited
- constraints → BoxConstraints
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTapOutside → TapRegionCallback?
-
final
- overlayEntry ↔ OverlayEntry?
-
getter/setter pairinherited
- props → CupertinoAutocompleteProps
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
inherited
-
getOverlayEntry(
BuildContext context) → OverlayEntry -
override
-
getOverlayPosition(
BuildContext pContext, MenuAlign? pAlign, BoxConstraints pConstraints) → RelativeRect -
return overlay position based on different params such, constrains, alignment and screen size
inherited
-
isOpen(
) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
BuildContext context) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited