CupertinoCustomMenu<T> class

Inheritance

Constructors

CupertinoCustomMenu({required BuildContext context, required BoxConstraints constraints, required CupertinoMenuProps props, required Widget child})

Properties

child Widget
final
constraints BoxConstraints
final
context BuildContext
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props CupertinoMenuProps
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRoute() Route<T>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMenu() Future<T?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited