CupertinoDialogProps class
Constructors
-
CupertinoDialogProps({bool barrierDismissible = false, String? barrierLabel, RouteSettings? routeSettings, Offset? anchorPoint, List<
Widget> ? actions, ScrollController? scrollController, ScrollController? actionScrollController, Duration insetAnimationDuration = const Duration(milliseconds: 100), Curve insetAnimationCurve = Curves.decelerate}) -
const
Properties
-
actions
→ List<
Widget> ? -
final
- actionScrollController → ScrollController?
-
final
- anchorPoint → Offset?
-
final
- barrierDismissible → bool
-
final
- barrierLabel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insetAnimationCurve → Curve
-
final
- insetAnimationDuration → Duration
-
final
- routeSettings → RouteSettings?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited