ChipProps class
see InputChip for details
Constructors
-
ChipProps({Widget? avatar, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, bool? selected, bool? isEnabled, ValueChanged<
bool> ? onSelected, Widget? deleteIcon, VoidCallback? onDeleted, Color? deleteIconColor, String? deleteButtonTooltipMessage, VoidCallback? onPressed, double? pressElevation, Color? disabledColor, Color? selectedColor, String? tooltip, BorderSide? side, OutlinedBorder? shape, Clip clipBehavior = Clip.none, FocusNode? focusNode, bool autofocus = false, WidgetStateProperty<Color?> ? color, Color? backgroundColor, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, MaterialTapTargetSize? materialTapTargetSize, double? elevation, Color? shadowColor, Color? surfaceTintColor, IconThemeData? iconTheme, Color? selectedShadowColor, bool? showCheckmark, Color? checkmarkColor, ShapeBorder avatarBorder = const CircleBorder(), BoxConstraints? avatarBoxConstraints, BoxConstraints? deleteIconBoxConstraints, ChipAnimationStyle? chipAnimationStyle}) -
const
Properties
- autofocus → bool
-
final
- avatar → Widget?
-
final
- avatarBorder → ShapeBorder
-
final
- avatarBoxConstraints → BoxConstraints?
-
final
- backgroundColor → Color?
-
final
- checkmarkColor → Color?
-
final
- chipAnimationStyle → ChipAnimationStyle?
-
final
- clipBehavior → Clip
-
final
-
color
→ WidgetStateProperty<
Color?> ? -
final
- deleteButtonTooltipMessage → String?
-
final
- deleteIcon → Widget?
-
final
- deleteIconBoxConstraints → BoxConstraints?
-
final
- deleteIconColor → Color?
-
final
- disabledColor → Color?
-
final
- elevation → double?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconTheme → IconThemeData?
-
final
- isEnabled → bool?
-
final
- labelPadding → EdgeInsetsGeometry?
-
final
- labelStyle → TextStyle?
-
final
- materialTapTargetSize → MaterialTapTargetSize?
-
final
- onDeleted → VoidCallback?
-
final
- onPressed → VoidCallback?
-
final
-
onSelected
→ ValueChanged<
bool> ? -
final
- padding → EdgeInsetsGeometry?
-
final
- pressElevation → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool?
-
final
- selectedColor → Color?
-
final
- selectedShadowColor → Color?
-
final
- shadowColor → Color?
-
final
- shape → OutlinedBorder?
-
final
- showCheckmark → bool?
-
final
- side → BorderSide?
-
final
- surfaceTintColor → Color?
-
final
- tooltip → String?
-
final
- visualDensity → VisualDensity?
-
final
Methods
-
copyWith(
{Widget? avatar, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, bool? selected, bool? isEnabled, ValueChanged< bool> ? onSelected, Widget? deleteIcon, VoidCallback? onDeleted, Color? deleteIconColor, String? deleteButtonTooltipMessage, VoidCallback? onPressed, double? pressElevation, Color? disabledColor, Color? selectedColor, String? tooltip, BorderSide? side, OutlinedBorder? shape, Clip? clipBehavior, FocusNode? focusNode, bool? autofocus, Color? backgroundColor, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, MaterialTapTargetSize? materialTapTargetSize, double? elevation, Color? shadowColor, Color? surfaceTintColor, Color? selectedShadowColor, bool? showCheckmark, Color? checkmarkColor, ShapeBorder? avatarBorder, IconThemeData? iconTheme, BoxConstraints? avatarBoxConstraints, BoxConstraints? deleteIconBoxConstraints, ChipAnimationStyle? chipAnimationStyle, WidgetStateProperty<Color?> ? color}) → ChipProps -
merge(
ChipProps? other) → ChipProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited