SuggestionsWidget<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SuggestionsWidget
Constructors
-
SuggestionsWidget({Key? key, ValueChanged<
T> ? onClick, required List<T> dropdownItems, required SuggestionsProps<T> props, required bool isSelectedItemFn(T item), required bool isDisabledItemFn(T item), required String itemAsString(T item), required UiToApply uiToApply}) -
const
Properties
-
dropdownItems
→ List<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisabledItemFn → bool Function(T item)
-
final
- isSelectedItemFn → bool Function(T item)
-
final
- itemAsString → String Function(T item)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onClick
→ ValueChanged<
T> ? -
final
-
props
→ SuggestionsProps<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uiToApply → UiToApply
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
suggestionsWidget(
SuggestedItemProps lItemProps, List< T> suggestedItems) → Widget -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited