WeighingMachineTO class
Constructors
- WeighingMachineTO({int? idWeighingMachine, int? createdBy, int? updatedBy, String? createdOn, String? updatedOn, num? weighingCapMT, String? machineName, String? codeNumber, String? machineDesc, String? location, int? locationId, String? deviceId, String? machineIP, bool? isTareWt, bool? isGrossWt, num? tareWt, num? grossWt, String? userIds, int? isActive})
-
WeighingMachineTO.fromJson(Map<
String, dynamic> json) -
factory
Properties
- codeNumber ↔ String?
-
getter/setter pair
- createdBy ↔ int?
-
getter/setter pair
- createdOn ↔ String?
-
getter/setter pair
- deviceId ↔ String?
-
getter/setter pair
- grossWt ↔ num?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- idWeighingMachine ↔ int?
-
getter/setter pair
- isActive ↔ int?
-
getter/setter pair
- isGrossWt ↔ bool?
-
getter/setter pair
- isTareWt ↔ bool?
-
getter/setter pair
- location ↔ String?
-
getter/setter pair
- locationId ↔ int?
-
getter/setter pair
- machineDesc ↔ String?
-
getter/setter pair
- machineIP ↔ String?
-
getter/setter pair
- machineName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tareWt ↔ num?
-
getter/setter pair
- updatedBy ↔ int?
-
getter/setter pair
- updatedOn ↔ String?
-
getter/setter pair
- userIds ↔ String?
-
getter/setter pair
- weighingCapMT ↔ num?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromDecodedJsonList(
List jsonList) → List< WeighingMachineTO>