DynamicData class
Constructors
-
DynamicData({int? idModule, String? module, int? parentId, int? createdBy, String? createdOn, int? updatedBy, String? updatedOn, bool? isActive, bool hasChildren = true, bool isExpanded = false, bool isLoading = false, List<
DynamicData> children = const []}) -
DynamicData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
↔ List<
DynamicData> -
getter/setter pair
- createdBy ↔ int?
-
getter/setter pair
- createdOn ↔ String?
-
getter/setter pair
- hasChildren ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- idModule ↔ int?
-
getter/setter pair
- isActive ↔ bool?
-
getter/setter pair
- isExpanded ↔ bool
-
getter/setter pair
- isLoading ↔ bool
-
getter/setter pair
- module ↔ String?
-
getter/setter pair
- parentId ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedBy ↔ int?
-
getter/setter pair
- updatedOn ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited