$AssetsIconsGen class
Constructors
- $AssetsIconsGen()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icCrm → String
-
File path: assets/icons/ic_crm.svg
no setter
- icDeliver → String
-
File path: assets/icons/ic_deliver.svg
no setter
- icEnquiry → String
-
File path: assets/icons/ic_enquiry.svg
no setter
- icExpense → String
-
File path: assets/icons/ic_expense.svg
no setter
- icFinance → String
-
File path: assets/icons/ic_finance.svg
no setter
- icMenu → AssetGenImage
-
File path: assets/icons/ic_menu.png
no setter
- icRecycle → String
-
File path: assets/icons/ic_recycle.svg
no setter
- icResolve → String
-
File path: assets/icons/ic_resolve.svg
no setter
- icSchedule → String
-
File path: assets/icons/ic_schedule.svg
no setter
- icSearch → AssetGenImage
-
File path: assets/icons/ic_search.png
no setter
- icSettings → String
-
File path: assets/icons/ic_settings.svg
no setter
- icStore → String
-
File path: assets/icons/ic_store.svg
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- values → List
-
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited