sessionHasExpired2 property
String
get
sessionHasExpired2
Implementation
static String get sessionHasExpired2 => LocalizationHelper.t("We notice that you aren't active in the session, so we logged you out for your safety. Please click on the button to log in again.");