ApiLog class
Constructors
-
ApiLog({required String id, required String module, required String screen, required String url, required String method, int? statusCode, required int responseTimeMs, Map<
String, String> ? requestHeaders, String? requestBody, String? responseBody, String? errorMessage, required bool success, required String platform, required DateTime timestamp}) - ApiLog.fromJson(String source)
-
factory
- ApiLog.fromMap(Map map)
-
factory
Properties
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- method → String
-
final
- module → String
-
final
- platform → String
-
final
- requestBody → String?
-
final
-
requestHeaders
→ Map<
String, String> ? -
final
- responseBody → String?
-
final
- responseTimeMs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen → String
-
final
- statusCode → int?
-
final
- success → bool
-
final
- timestamp → DateTime
-
final
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited