DownloadServiceForBoth class
- Implemented types
Constructors
Properties
- dio → Dio
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- repo → DownloadRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
DownloadItem item) → Future< void> -
override
-
downloadFile(
{required DownloadItem item, required dynamic onProgress(int, int)}) → Future< void> -
override
-
initialize(
void callback(String id, int status, int progress)) → Future< void> -
override
-
loadPersistedTasks(
) → Future< List< DownloadItem> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openFile(
DownloadItem item) → Future< void> -
override
-
pause(
DownloadItem item) → Future< void> -
override
-
resume(
DownloadItem item) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited