AppConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- aclPositionMappingIdKey → const String
- aclPositionMappingNameKey → const String
- departmentIdKey → const String
- divisionIdKey → const String
- firstTimeLoginKey → const String
- isDarkModeKey → const String
- isLoggedInKey → const String
- itemsKey → const String
- latitudeKey → const String
- localeKey → const String
- locationPermission → const String
- loggedInPassword → const String
- loggedInUserName → const String
- longitudeKey → const String
- notificationPermission → const String
- organizationIdKey → const String
- profileKey → const String
- roleIdKey → const String
- tokenKey → const String
- userDepartments → const String
- userIdKey → const String
- userName → const String
- userRoles → const String