AppFontFamily enum
Values
- system → const AppFontFamily
- roboto → const AppFontFamily
- openSans → const AppFontFamily
- lato → const AppFontFamily
- nunito → const AppFontFamily
- merriweather → const AppFontFamily
Properties
- fontFamily → String?
-
The actual font-family string to pass to Flutter TextStyle.
Returns null for system so Flutter uses the platform default.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - previewText → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppFontFamily> - A constant List of the values in this enum, in order of their declaration.