CustomSelectionManager class
Properties
-
dataGridController
↔ DataGridController
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
handleDataGridSourceChanges()
→ void
-
Called when the selection is programmatically changed
using
SfDataGrid.controller.
inherited
-
handleKeyEvent(KeyEvent keyEvent)
→ Future<void>
-
Processes the selection operation when
SfDataGrid receives raw keyboard
event.
-
handleTap(RowColumnIndex rowColumnIndex)
→ void
-
Processes the selection operation when tap a cell.
inherited
-
isIndexOutsideRange(int pressedRowIndex, int currentRecordIndex, int index)
→ bool
-
Check whether the index is outside the shift selected rows range.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
onGridSelectionModeChanged()
→ void
-
Called when the
SfDataGrid.selectionMode is changed at run time.
inherited
-
onSelectedIndexChanged()
→ void
-
Called when the selectedIndex property in
SfDataGrid.controller
is changed.
inherited
-
onSelectedRowChanged()
→ void
-
Called when the selectedRow property in
SfDataGrid.controller
is changed.
inherited
-
onSelectedRowsChanged()
→ void
-
Called when the selectedRows property in
SfDataGrid.controller
is changed.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited