ResponsiveUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
columnWidthMode(
BuildContext context) → ColumnWidthMode - On mobile : auto → content-sized columns, user scrolls horizontally. On web/desk: lastColumnFill → respects minimumWidth on every column except the last, which fills remaining space. This is the fix for ColumnWidthMode.fill silently clipping headers when total min-widths exceed the available width.
-
frozenColumns(
BuildContext context, {int requested = 0}) → int -
horizontalPhysics(
BuildContext context) → ScrollPhysics -
isDesktop(
BuildContext context) → bool -
isMobile(
BuildContext context) → bool -
isTablet(
BuildContext context) → bool -
resolve<
T> (BuildContext context, {required T mobile, required T tablet, required T desktop}) → T