AppLoaderColor enum
Values
- accent → const AppLoaderColor
-
const AppLoaderColor('Match Brand Color', null) - blue → const AppLoaderColor
-
const AppLoaderColor('Deep Blue', Color(0xFF00457A)) - indigo → const AppLoaderColor
-
const AppLoaderColor('Indigo', Color(0xFF4F46E5)) - emerald → const AppLoaderColor
-
const AppLoaderColor('Emerald Green', Color(0xFF059669)) - rose → const AppLoaderColor
-
const AppLoaderColor('Rose Red', Color(0xFFE11D48)) - amber → const AppLoaderColor
-
const AppLoaderColor('Amber Gold', Color(0xFFD97706)) - teal → const AppLoaderColor
-
const AppLoaderColor('Modern Teal', Color(0xFF0D9488)) - custom → const AppLoaderColor
-
const AppLoaderColor('Custom Color', Color(0xFF00457A))
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppLoaderColor> - A constant List of the values in this enum, in order of their declaration.