AppPageTransition enum
Values
- fadeIn → const AppPageTransition
-
const AppPageTransition('Fade In (Sleek)') - rightToLeft → const AppPageTransition
-
const AppPageTransition('Slide Right to Left') - leftToRight → const AppPageTransition
-
const AppPageTransition('Slide Left to Right') - upToDown → const AppPageTransition
-
const AppPageTransition('Slide Top to Bottom') - downToUp → const AppPageTransition
-
const AppPageTransition('Slide Bottom to Top') - zoom → const AppPageTransition
-
const AppPageTransition('Zoom / Scaling') - cupertino → const AppPageTransition
-
const AppPageTransition('iOS Cupertino Style') - noTransition → const AppPageTransition
-
const AppPageTransition('None / Instant')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppPageTransition> - A constant List of the values in this enum, in order of their declaration.