AppSidebarColor enum
Values
- darkCharcoal → const AppSidebarColor
-
const AppSidebarColor('Dark Charcoal', Color(0xFF1E1E1E), Colors.white) - deepBlue → const AppSidebarColor
-
const AppSidebarColor('Deep Blue', Color(0xFF0F172A), Colors.white) - classicWhite → const AppSidebarColor
-
const AppSidebarColor('Classic White', Color(0xFFF8FAFC), Color(0xFF0F172A)) - slateGrey → const AppSidebarColor
-
const AppSidebarColor('Slate Grey', Color(0xFF334155), Colors.white) - emerald → const AppSidebarColor
-
const AppSidebarColor('Emerald Dark', Color(0xFF064E3B), Colors.white) - custom → const AppSidebarColor
-
const AppSidebarColor('Custom Color', Color(0xFF0F172A), Colors.white)
Properties
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppSidebarColor> - A constant List of the values in this enum, in order of their declaration.