FileUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertAndSaveBase64(
{required String base64String, required String fileName}) → Future< void> -
saveBytes(
{required Uint8List bytes, required String fileName}) → Future< void> -
saveFile(
{required String fileName, required List< int> bytes, required String extension, required MimeType mimeType}) → Future<void>