RadiusUtils class

Constructors

RadiusUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

borderRadiusExtraLarge BorderRadius
getter/setter pair
borderRadiusForButtons BorderRadius
getter/setter pair
borderRadiusForDataGrid BorderRadius
getter/setter pair
borderRadiusLarge BorderRadius
getter/setter pair
borderRadiusMedium BorderRadius
getter/setter pair
borderRadiusNormal BorderRadius
getter/setter pair
borderRadiusSmall BorderRadius
getter/setter pair

Static Methods

customRadius(double radius) BorderRadius
dataGridRadius() BorderRadius

Constants

extraLargeRadius → const Radius
largeRadius → const Radius
mediumRadius → const Radius
normalRadius → const Radius
smallRadius → const Radius