TextStyles class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
appBarTitle(BuildContext context, {Color? textColor})
→ TextStyle
-
-
buttonTextStyle(BuildContext context, Color? color)
→ TextStyle
-
-
-
-
heading1(BuildContext context, {Color? textColor})
→ TextStyle
-
-
heading2(BuildContext context, {Color? textColor})
→ TextStyle
-
-
heading3(BuildContext context, {Color? textColor})
→ TextStyle
-
-
heading4(BuildContext context, {Color? textColor})
→ TextStyle
-
-
huge(BuildContext context, {Color? textColor})
→ TextStyle
-
-
large(BuildContext context, {Color? textColor})
→ TextStyle
-
-
largeBold(BuildContext context, {Color? textColor})
→ TextStyle
-
-
medium(BuildContext context, {Color? textColor})
→ TextStyle
-
-
mediumBold(BuildContext context, {Color? textColor})
→ TextStyle
-
-
normal(BuildContext context, {Color? textColor, double? size})
→ TextStyle
-
-
normalBold(BuildContext context, {Color? textColor, FontWeight? fontWeight})
→ TextStyle
-
-
small(BuildContext context, {Color? textColor})
→ TextStyle
-
-
tabStyle({Color? textColor})
→ TextStyle
-