AppDropDownWithSingleSelection class

Inheritance

Constructors

AppDropDownWithSingleSelection({Key? key, double? width, required Rx<DropDownResponse?> selectedId, required RxList<DropDownResponse> listItems, required String hintText, required VoidCallback onClearPressed, dynamic onItemSelected(DropDownResponse)?, bool isAPISearchEnabled = false, bool isShowAddNewButton = false, bool isShowResetButton = false, bool isPaginationEnabled = false, bool isValidator = false, dynamic onSearchRequest(String)?, VoidCallback? onReset, VoidCallback? onAddNew, String? validator(String?)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hintText String
final
isAPISearchEnabled bool
final
isPaginationEnabled bool
final
isShowAddNewButton bool
final
isShowResetButton bool
final
isValidator bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listItems → RxList<DropDownResponse>
final
onAddNew VoidCallback?
final
onClearPressed VoidCallback
final
onItemSelected → dynamic Function(DropDownResponse)?
final
onReset VoidCallback?
final
onSearchRequest → dynamic Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedId → Rx<DropDownResponse?>
final
validator String? Function(String?)?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getSelectedValue() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited