AppTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppTextField
Constructors
-
AppTextField({Key? key, double? height = 40.0, double? width, String? floatingHint, String? initialValue, double? contentPadding = 5.0, TextEditingController? controller, void onSaved(String?)?, int? maxLines = 1, int? minLines = 1, FormFieldValidator<
String> ? validator, Color? hintColor, Color? textColor, Color? underlineColor, TextInputType? keyboardType, bool? showPasswordType = false, bool? enabled = true, void onTap()?, bool? autoFocus = false, double? fontSize = 13.0, int? maxLength, TextAlign? textAlign = TextAlign.start, FocusNode? focusNode, Color? cursorColor, String? hint, String? errorText, FontWeight? fontWeight, bool? isRoundedBorer = false, Color? borderColor, double? borderRadius = 10, double? borderWidth = 1.0, bool? autovalidate = false, Color? disabledColor, TextInputAction? textInputAction, Widget? icon, Widget? suffixIcon, Widget? prefixIcon, String? suffixText, TextStyle? suffixStyle, String? prefixText, TextStyle? prefixStyle, ValueChanged<String> ? onChanged, ValueChanged<String> ? onSubmitted, ValueChanged<String> ? onFieldSubmitted, InputDecoration? decoration = const InputDecoration(), VoidCallback? onEditingComplete, TextCapitalization? textCaps, bool? autoCorrect, List<TextInputFormatter> ? inputFormatters, Iterable<String> ? autofillHints, bool isSearchTextField = false, bool isValidator = false, bool isEmail = false})
Properties
- autoCorrect → bool?
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autoFocus → bool?
-
final
- autovalidate → bool?
-
final
- borderColor → Color?
-
final
- borderRadius → double?
-
final
- borderWidth → double?
-
final
- contentPadding → double?
-
final
- controller → TextEditingController?
-
final
- cursorColor → Color?
-
final
- decoration → InputDecoration?
-
final
- disabledColor → Color?
-
final
- enabled → bool?
-
final
- errorText → String?
-
final
- floatingHint → String?
-
final
- focusNode → FocusNode?
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- hint → String?
-
final
- hintColor → Color?
-
final
- icon → Widget?
-
final
- initialValue → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isEmail → bool
-
final
- isRoundedBorer → bool?
-
final
- isSearchTextField → bool
-
final
- isValidator → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onEditingComplete → VoidCallback?
-
final
-
onFieldSubmitted
→ ValueChanged<
String> ? -
final
- onSaved → void Function(String?)?
-
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- onTap → void Function()?
-
final
- prefixIcon → Widget?
-
final
- prefixStyle → TextStyle?
-
final
- prefixText → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPasswordType → bool?
-
final
- suffixIcon → Widget?
-
final
- suffixStyle → TextStyle?
-
final
- suffixText → String?
-
final
- textAlign → TextAlign?
-
final
- textCaps → TextCapitalization?
-
final
- textColor → Color?
-
final
- textInputAction → TextInputAction?
-
final
- underlineColor → Color?
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited