getClip method
Returns a description of the clip given that the render object being clipped is of the given size.
Implementation
@override
Path getClip(Size size) {
final path = Path();
path.moveTo(size.width, 0); // Start from top-right corner
path.quadraticBezierTo(
0, size.height / 2, size.width, size.height); // Create left curve
path.lineTo(size.width, size.height); // Move back to the bottom-right
path.close();
return path;
}