CustomDropdownMulti class

Inheritance

Constructors

CustomDropdownMulti({Key? key, double? width, bool isEnabled = true, bool isAddNewButton = false, void onAddNewPressed()?, List<DropDownResponse>? items, Future<List<DropDownResponse>> fetchData(String filter)?, required void onChanged(List<DropDownResponse> selectedItem), List<DropDownResponse>? selectedItem, String hintText = 'Select Items', bool isValidator = false, String? validationMessage, required GlobalKey<DropdownSearchState<DropDownResponse>> dropDownKey})

Properties

final
final
fetchData Future<List<DropDownResponse>> Function(String filter)?
For API-based list
final
hashCode int
The hash code for this object.
no setterinherited
hintText String
final
isAddNewButton bool
final
isEnabled bool
final
isValidator bool
final
items List<DropDownResponse>?
For static list
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAddNewPressed → void Function()?
final
onChanged → void Function(List<DropDownResponse> selectedItem)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItem List<DropDownResponse>?
final
validationMessage String?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildAddNewButton() Widget
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getSelectedValues(int value) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited