CustomDropdownSingle class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomDropdownSingle
Constructors
-
CustomDropdownSingle({Key? key, double? width, required String hintText, required DropDownResponse? selectedItem, bool isEnabled = true, bool isAddNewButton = false, bool isAddManually = false, List<
DropDownResponse> ? items, Future<List< fetchData(String)?, VoidCallback? onAddNewPressed, ValueChanged<DropDownResponse> >String?> ? onManuallyPressed, String? validationMessage, ValueChanged<DropDownResponse?> ? onChanged, bool isValidator = false, GlobalKey<DropdownSearchState< ? dropDownKey, VerticalDirection direction = VerticalDirection.down})DropDownResponse> >
Properties
- direction → VerticalDirection
-
final
-
dropDownKey
→ GlobalKey<
DropdownSearchState< ?DropDownResponse> > -
final
-
fetchData
→ Future<
List< Function(String)?DropDownResponse> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String
-
final
- isAddManually → bool
-
final
- isAddNewButton → bool
-
final
- isEnabled → bool
-
final
- isValidator → bool
-
final
-
items
→ List<
DropDownResponse> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAddNewPressed → VoidCallback?
-
final
-
onChanged
→ ValueChanged<
DropDownResponse?> ? -
final
-
onManuallyPressed
→ ValueChanged<
String?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItem ↔ DropDownResponse?
-
getter/setter pair
- validationMessage → String?
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomDropdownSingle> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited